@@ -12,8 +12,10 @@ Graph::~Graph()
 {
 }
 /********************************************************************************************/
-void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDists0, double *preDists, int *toroidal0, int *dbg0)
+void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDists0,
+		double *preDists, int *toroidal0, int *inc0, double *wMatrix, int *dbg0)
 {
+	int typein,i,j;
 	if(*dbg0)printf("intializing graph-object... ");
 
 	pp = pp0;
@@ -24,10 +26,31 @@ void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDist
 	oldpar = &opar;
 	doDists=doDists0;
 	dbg=dbg0;
+	inc = inc0;
 	nodelist.resize(pp->size());
 	gtype = gtype0;
 	mdeg = 0.0;
 	pp->setToroidal(toroidal0);
+	typeIncluded.clear();
+	weightMatrix = wMatrix;
+
+	if(weightMatrix[0]<0)getTypeToTypeWeightp = &Graph::getTypeToTypeWeight_all1; // if no weights given
+	else{
+		if(*dbg)printf("Type-to-Type weight matrix received.\n");
+		getTypeToTypeWeightp = &Graph::getTypeToTypeWeight_weighted; // weights given
+	}
+
+	for(i=0; i< pp->getNtypes(); i++)//need to ignore some types based on the inclusion vector
+	{
+		typein=0;
+		for(j=0;j< pp->size(); j++)
+			if( (pp->getT(&j) == pp->getTypevec(&i)) & inc[j])
+			{
+				typein=1;
+				break;
+			}
+		typeIncluded.push_back(typein);
+	}
 
 	if(preDists[0]>=0)
 	{
@@ -85,6 +108,7 @@ SEXP Graph::toSEXP()
 		this->nodelist[i].clear();
 		SET_VECTOR_ELT(graph, i, *node);
 		UNPROTECT(1);
+		delete node;
 	}
 	UNPROTECT(1);
 	return graph;
@@ -134,6 +158,20 @@ void Graph::addNew(int i, int j)
 		nodelist.at(i).push_back(j);
 }
 /********************************************************************************************/
+/********************************************************************************************/
+// Weight matrix functions
+double Graph::getTypeToTypeWeight(int *t1, int *t2){
+	return (this->*getTypeToTypeWeightp)(t1,t2);
+}
+// if truly weighted
+double Graph::getTypeToTypeWeight_weighted(int *t1, int *t2){
+	return weightMatrix[(*t2-1)*pp->getNtypes()+(*t1-1)];
+}
+// otherwise
+double Graph::getTypeToTypeWeight_all1(int *t1, int *t2){
+	return 1;
+}
+/********************************************************************************************/
 //The graph methods
 /********************************************************************************************/
 void Graph::sg_calc()
@@ -171,6 +209,8 @@ void Graph::sg_calc()
 	else if(*gtype==9) this->sg_RNG();
 	else if(*gtype==10) this->sg_CCC();
 	else if(*gtype==11) this->sg_STIR();
+	else if(*gtype==12) this->sg_big_geometric();
+	preEdges = 1;
 }
 
 /********************************************************************************************/
@@ -197,6 +237,26 @@ void Graph::sg_geometric(double *R)
 	if(*dbg)printf(" Ok.");
 }
 
+void Graph::sg_big_geometric()
+{
+	if(*dbg)printf("Big geometric (R=%f):",*par);
+	int i,j;
+	double dist;
+	for(i=0;i<pp->size();i++)
+		if(inc[i])
+			for(j=0;j<pp->size();j++)
+				if(i!=j)
+				{
+					dist = pp->getDist(&i, &j);
+					if(dist<*par){
+						nodelist[i].push_back(j+1);
+					}
+				}
+	mdeg = this->pp->lambda*PI*(*par)*(*par);
+	if(*dbg)printf(" Ok.");
+	*gtype = 0;
+}
+
 void Graph::sg_shrink_geometric(double *R)
 {
 	if(*dbg)printf("Geometric (R=%f) (shrinking):",*R);
@@ -204,18 +264,19 @@ void Graph::sg_shrink_geometric(double *R)
 	double dist;
 	std::vector<int> *node;
 	for(i=0; i < pp->size() ; i++)
-	{
-		node = new std::vector<int>;
-		for(j=0;j < (int) this->nodelist[i].size() ; j++)
+		if(inc[i])
 		{
-			j0 = nodelist[i][j]-1;
-			dist = pp->getDist(&i,&j0);
-			if(dist<*R)
-				node->push_back(j0+1);
-		}
-		nodelist[i].clear();nodelist[i].resize(0);
-		for (j = 0; j < (int)node->size(); ++j) this->nodelist[i].push_back(node->at(j));
-		delete node;
+			node = new std::vector<int>;
+			for(j=0;j < (int) this->nodelist[i].size() ; j++)
+			{
+				j0 = nodelist[i][j]-1;
+				dist = pp->getDist(&i,&j0);
+				if(dist<*R)
+					node->push_back(j0+1);
+			}
+			nodelist[i].clear();nodelist[i].resize(0);
+			for (j = 0; j < (int)node->size(); ++j) this->nodelist[i].push_back(node->at(j));
+			delete node;
 	}
 	mdeg = this->pp->lambda*PI*(*R)*(*R);
 	if(*dbg)printf(" ok.");
@@ -253,6 +314,7 @@ void Graph::sg_knn()
 		if(*dbg)printf("%i-nn:",*k);
 		double *dists2_i = new double[pp->size()], *dists2_i2 = new double[pp->size()];
 		for(i=0;i<pp->size();i++) //for each point
+		if(inc[i])
 		{
 			for(j=0;j<pp->size();j++) dists2_i2[j]=dists2_i[j]= pp->getDist(&i, &j); //gather the distances to others
 			qsort( dists2_i, pp->size(), sizeof(double),compare_doubles); // sort distances, rising
@@ -263,13 +325,13 @@ void Graph::sg_knn()
 						nodelist[i].push_back(l+1);
 						break;
 					}
-
 		}
 	}
 	else{ //preprocessed
 		if(*dbg)printf("%i-nn (shrinking):",*k);
 		double *dists2_i, *dists2_i2;
 		for(i=0;i<pp->size();i++) //for each point
+		if(inc[i])
 		{
 			node = new std::vector<int>;
 			dists2_i = new double [nodelist[i].size()];
@@ -329,8 +391,8 @@ void Graph::sg_gabriel()
 	  {
 		  for(j=i+1;j<pp->size();j++)
 		  {
-			  x0 = fabs(pp->getX(&i)-pp->getX(&j))/2.0+fmin2(pp->getX(&i),pp->getX(&j));
-			  y0 = fabs(pp->getY(&i)-pp->getY(&j))/2.0+fmin2(pp->getY(&i),pp->getY(&j));
+			  x0 = fabs(pp->getX(&i)-pp->getX(&j))/2.0+fmin(pp->getX(&i),pp->getX(&j));
+			  y0 = fabs(pp->getY(&i)-pp->getY(&j))/2.0+fmin(pp->getY(&i),pp->getY(&j));
 			  R2 = ( pow(pp->getX(&i)-pp->getX(&j),2) + pow(pp->getY(&i)-pp->getY(&j),2) )/4.0;
 			  //		brute force
 			  empty = 1+kk;
@@ -357,36 +419,39 @@ void Graph::sg_gabriel()
 		if(*dbg)printf("(prepd): ");
 		for(i = 0 ; i< pp->size() ;  i++)
 		{
-			node = new std::vector<int>;
-			for( l=0 ; l < (int) this->nodelist[i].size(); l++ )
+			if(inc[i])
 			{
-				j = this->nodelist[i][l]-1;
-				x0 = fabs(this->pp->getX(&i)-this->pp->getX(&j))/2.0+fmin2(this->pp->getX(&i),this->pp->getX(&j));
-				y0 = fabs(this->pp->getY(&i)-this->pp->getY(&j))/2.0+fmin2(this->pp->getY(&i),this->pp->getY(&j));
-				R2 = (pow(this->pp->getX(&i)-this->pp->getX(&j),2) + pow(this->pp->getY(&i)-this->pp->getY(&j),2) )/4.0;
-				empty = 1+kk;
-				for(m=0; m <(int) this->nodelist[i].size();m++) // the small ball is included in the preprocessing ball
+				node = new std::vector<int>;
+				for( l=0 ; l < (int) this->nodelist[i].size(); l++ )
 				{
-					k =  (int) this->nodelist[i][m]-1;
-					if(k != i)
-						if( k != j)
-						{
-							d = pow(x0-pp->getX(&k),2) + pow(y0-pp->getY(&k),2);
-							if( d<R2 )
+					j = this->nodelist[i][l]-1;
+					x0 = fabs(this->pp->getX(&i)-this->pp->getX(&j))/2.0+fmin(this->pp->getX(&i),this->pp->getX(&j));
+					y0 = fabs(this->pp->getY(&i)-this->pp->getY(&j))/2.0+fmin(this->pp->getY(&i),this->pp->getY(&j));
+					R2 = (pow(this->pp->getX(&i)-this->pp->getX(&j),2) + pow(this->pp->getY(&i)-this->pp->getY(&j),2) )/4.0;
+					empty = 1+kk;
+					for(m=0; m <(int) this->nodelist[i].size();m++) // the small ball is included in the preprocessing ball
+					{
+						k =  (int) this->nodelist[i][m]-1;
+						if(k != i)
+							if( k != j)
 							{
-								empty = empty - 1;
-								if(empty == 0) break;
+								d = pow(x0-pp->getX(&k),2) + pow(y0-pp->getY(&k),2);
+								if( d<R2 )
+								{
+									empty = empty - 1;
+									if(empty == 0) break;
+								}
 							}
-						}
-				}
-				if(empty)
-				{
-					node->push_back(j+1);
+					}
+					if(empty)
+					{
+						node->push_back(j+1);
+					}
 				}
+				nodelist[i].clear();nodelist[i].resize(0);
+				for(h=0;h<(int)node->size();h++) nodelist[i].push_back(node->at(h));
+				delete node;
 			}
-			nodelist[i].clear();nodelist[i].resize(0);
-			for(h=0;h<(int)node->size();h++) nodelist[i].push_back(node->at(h));
-			delete node;
 		}
 	}
 	mdeg = 4;
@@ -419,23 +484,26 @@ void Graph::sg_delaunay()
 		if(*dbg)printf("(prepd): ");
 		for(i = 0 ; i< pp->size() ;  i++)
 		{
-			node = new std::vector<int>;
-			for( l=0 ; l < (int)nodelist[i].size()-1; l++ )
+			if(inc[i])
 			{
-				j = nodelist[i][l]-1;
-				for(h=l+1; h < (int)nodelist[i].size();h++ )
+				node = new std::vector<int>;
+				for( l=0 ; l < (int)nodelist[i].size()-1; l++ )
 				{
-					k = nodelist[i][h]-1;
-					if( pp->Empty(&i, &j, &k) )
+					j = nodelist[i][l]-1;
+					for(h=l+1; h < (int)nodelist[i].size();h++ )
 					{
-						node->push_back(j+1);
-						node->push_back(k+1);
+						k = nodelist[i][h]-1;
+						if( pp->EmptyConstrained(&i, &j, &k, &nodelist.at(i)) )
+						{
+							node->push_back(j+1);
+							node->push_back(k+1);
+						}
 					}
 				}
+				nodelist[i].clear();nodelist[i].resize(0);
+				for(h=0;h<(int)node->size();h++) nodelist[i].push_back((*node).at(h));
+				delete node;
 			}
-			nodelist[i].clear();nodelist[i].resize(0);
-			for(h=0;h<(int)node->size();h++) nodelist[i].push_back((*node).at(h));
-			delete node;
 		}
 		this->remove_duplicates();
 	}
@@ -513,7 +581,7 @@ void Graph::sg_SIG()
 	{
 		dist = MAX_DOUBLE;
 		for(j=0;j<pp->size();j++)
-			if(i!=j) dist = fmin2(dist, pp->getDist(&i, &j));
+			if(i!=j) dist = fmin(dist, pp->getDist(&i, &j));
 		pp->setMass(&i,&dist);
 	}
 	*dbg=0;
@@ -593,7 +661,7 @@ void Graph::sg_CCC()
 			for(j=0;j<pp->size();j++)
 				if( (j!=i) & (pp->getT(&j)!=type0) )
 				{
-					apu = fmin2(pp->getMass(&i),pp->getDist(&i, &j));
+					apu = fmin(pp->getMass(&i),pp->getDist(&i, &j));
 					pp->setMass(&i, &apu);
 				}
 		}
@@ -633,7 +701,7 @@ void Graph::sg_STIR()
 			sji = pp->getMass(&j)*Attenuate(pp->getDist(&i, &j),alpha);
 			sij = sij/(noise0 + gamma* (noise[j]-sij));
 			sij = sji/(noise0 + gamma* (noise[i]-sji));
-			s = fmin2(sij,sji);
+			s = fmin(sij,sji);
 			if(s >= beta )
 			{
 				addNew(i,j+1);
